<?php
/* --------------------------------------------------------------
   SpecialOfferReader.inc.php 2018-07-02
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

class SpecialOfferReader implements SpecialOfferReaderInterface
{
	/**
	 * @var \CI_DB_query_builder
	 */
	protected $db;
	
	/**
	 * @var string
	 */
	protected $table = 'specials';
	
	
	/**
	 * SpecialOfferReader constructor.
	 *
	 * @param \CI_DB_query_builder $db
	 */
	public function __construct(CI_DB_query_builder $db)
	{
		$this->db = $db;
	}
	
	
	/**
	 * Fetches special offer data by the given id.
	 *
	 * @param \IdType $specialOfferId Id of expected special offer data.
	 *
	 * @return array|null Raw data of a special offer.
	 */
	public function fetchById(IdType $specialOfferId)
	{
		return $this->db->select()
		                ->from($this->table)
		                ->where('specials_id', $specialOfferId->asInt())
		                ->get()
		                ->row_array();
	}
	
	
	/**
	 * Fetches special offer data by the given condition.
	 *
	 * @param \IntType    $limit           Quantity of returned items.
	 * @param \IntType    $offset          Offset of returned items.
	 * @param \StringType $searchCondition Search condition for special offer data.
	 *
	 * @return array|null Raw data of special offers.
	 */
	public function fetchBy(IntType $limit, IntType $offset, StringType $searchCondition)
	{
		return $this->db->select()
		                ->from($this->table)
		                ->where($searchCondition->asString(), null, false)
		                ->limit($limit->asInt(), $offset->asInt())
		                ->get()
		                ->result_array();
	}
	
	
	/**
	 * Returns all special offers.
	 *
	 * @param \IntType $limit  Quantity of returned items.
	 * @param \IntType $offset Offset of returned items.
	 *
	 * @return array|null Raw data of special offers.
	 */
	public function fetchAll(IntType $limit, IntType $offset)
	{
		return $this->db->select()->from($this->table)->limit($limit->asInt(), $offset->asInt())->get()->result_array();
	}
}